import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';
//D3 se base sur canvas => render car rendu en svg
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { //expliquer
  
const xValue = d => d.year; //display dates sur x axis
const xAxisLabel = 'Year';

  const yValue = d => d.profits;
  const yAxisLabel = 'Profits';
  
  const margin = { top: 80, right: 50, bottom: 99, left: 160 };//mm manière que CSS
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  //container
  
  const xScale = scaleTime()
  //complete set of values
    .domain(extent(data, xValue)) //returns the minimum and maximum value in an array from the given array using natural order.
    .range([0, innerWidth]) //output bounds
    .nice(); //round values out
  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);//center g in svg
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(30);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);
  
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -80)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-80)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); //coordinates in pixels
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
    console.log(lineGenerator(data))
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -15)
      .text(title);
};

csv('https://gist.githubusercontent.com/Tejaswi221/9e88652015da54a0fec7749298d907cc/raw/836f2a520ec008c548a9a4b9df45e187fe583ec3/Profits%2520of%2520a%2520Company')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.profits= +d.profits;
      d.year = new Date(d.year)
    });
  console.log(data)
    render(data);
  })